Acknowledgements
-----------------
`neutcurve` is written by the `Bloom lab  <https://research.fhcrc.org/bloom/en.html>`_.

See https://github.com/jbloomlab/neutcurve/graphs/contributors for the full list of contributors.

Please cite `Loes et al (2024) <https://doi.org/10.1101/2024.03.08.584176>`_ if you use `neutcurve` in your scientific study.
